
.. py:module:: pyvo.dal

********************
The pyvo.dal Package
********************

The ``pyvo.dal`` module encapsulates the implementation of the DAL
services.  The :py:mod:`~pyvo.dal.query` sub-module provides DAL
behaviors through a set of base classes and common exception classes.
The implementations for the specific types of services are handle the
sub-modules :py:mod:`~pyvo.dal.scs`, :py:mod:`~pyvo.dal.sia`, 
:py:mod:`~pyvo.dal.ssa`, :py:mod:`~pyvo.dal.sla`, :py:mod:`~pyvo.dal.tap`

.. automodapi:: pyvo.dal.query
.. automodapi:: pyvo.dal.scs
.. automodapi:: pyvo.dal.sia
.. automodapi:: pyvo.dal.ssa
.. automodapi:: pyvo.dal.sla
.. automodapi:: pyvo.dal.tap
